@@ -12,10 +12,15 @@
 #'   "right", "bottom", "center", "top"). The \code{angle} aesthetics can be
 #'   used to rotate the inset plots.
 #'
-#' @section Inset size: You can modify inset plot size with the \code{vp.width}
-#'   and \code{vp.height} aesthetics. These can be a number between 0 (smallest
-#'   possible inset) and 1 (whole plotting area width or height). The default
-#'   value for for both of these aesthetics is 1/3.
+#' @section Inset size and aspect: You can modify the size of the inset plot
+#'   with the \code{vp.width} and \code{vp.height} aesthetics. Arguments can be
+#'   a number between 0 (smallest possible inset) and 1 (whole plotting area
+#'   width or height). The default value for for both of these aesthetics is
+#'   1/3. If the coordinates are "free" the plot stretches to fill the viewport.
+#'   However, if the coordinates of the inset are "fixed" and the aspect ratio
+#'   of the viewport is different to that of the inset, the viewport will be
+#'   surrounded on either $x$ or $y$ margins by invisible space, which may look
+#'   as if the position of the inset is wrong.
 #'
 #' @param mapping The aesthetic mapping, usually constructed with
 #'   \code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_}}. Only needs to be
@@ -98,6 +103,12 @@
 #'   expand_limits(x = 0, y = 0) +
 #'   geom_plot_npc(data = df, aes(npcx = x, npcy = y, label = plot))
 #'
+#' p +
+#'   expand_limits(x = 0, y = 0) +
+#'   geom_plot_npc(data = df,
+#'                 vp.width = 1/2, vp.height = 1/4,
+#'                 aes(npcx = x, npcy = y, label = plot))
+#'
 geom_plot <- function(mapping = NULL, data = NULL,
                        stat = "identity", position = "identity",
                        ...,
@@ -133,7 +144,8 @@ gplot_draw_panel_fun <-
     }
 
     if (!is.ggplot(data$label[[1]])) {
-      warning("Skipping as object mapped to 'label' is not a list of \"gg\" or \"ggplot\" objects.")
+      warning("Skipping as object mapped to 'label' is not",
+              " a list of \"gg\" or \"ggplot\" objects.")
       return(grid::nullGrob())
     }
 
@@ -152,16 +164,17 @@ gplot_draw_panel_fun <-
       plotGrob <-
         ggplotGrob(x = data$label[[row.idx]])
 
-      plotGrob$vp <- grid::viewport(x = unit(data$x[row.idx], "native"),
-                               y = unit(data$y[row.idx], "native"),
-                               width = unit(data$vp.width[row.idx], "npc"),
-                               height = unit(data$vp.height[row.idx], "npc"),
-                               just = c(data$hjust[row.idx],
-                                        data$vjust[row.idx]),
-                               angle = data$angle[row.idx],
-                               name = paste("geom_plot.panel",
-                                            data$PANEL[row.idx], "row",
-                                            row.idx, sep = "."))
+      plotGrob$vp <-
+        grid::viewport(x = unit(data$x[row.idx], "native"),
+                       y = unit(data$y[row.idx], "native"),
+                       width = unit(data$vp.width[row.idx], "npc"),
+                       height = unit(data$vp.height[row.idx], "npc"),
+                       just = c(data$hjust[row.idx],
+                                data$vjust[row.idx]),
+                       angle = data$angle[row.idx],
+                       name = paste("geom_plot.panel",
+                                    data$PANEL[row.idx], "row",
+                                    row.idx, sep = "."))
 
       # give unique name to each plot
       plotGrob$name <- paste("inset.plot", row.idx, sep = ".")
@@ -184,9 +197,15 @@ GeomPlot <-
           required_aes = c("x", "y", "label"),
 
           default_aes = aes(
-            colour = "black", angle = 0, hjust = "inward",
-            vjust = "inward", alpha = NA, family = "", fontface = 1,
-            vp.width = 0.4, vp.height = 0.4
+            colour = "black",
+            angle = 0,
+            hjust = "inward",
+            vjust = "inward",
+            alpha = NA,
+            family = "",
+            fontface = 1,
+            vp.width = 0.4,
+            vp.height = 0.4
           ),
 
           draw_panel = gplot_draw_panel_fun,
